class firefield {

  # Backup definition
  # Will be used in nodes for setup the backup
  # Add the fragment for server backups and create the config
  # for backups on demand
  define backup_def_rails_app(
    $db_name,
    $db_user,
    $db_pass,
    $application_deploy_dir,
  )
  {
    # Fragment for rails server backup
    concat::fragment{ $name :
      target => $backup_rails_server::backup_cfg,
      content => template("firefield/backups/rails_server_fragments/10_rails_app.erb"),
      order   => 1,
    }

  }

  # Backup all apps for a rails server
  class backup_rails_server(
    $s3_access_key_id,
    $s3_secret_access_key,
    $s3_region,
    $s3_bucket,
    $s3_path = "/${fqdn}",
    $s3_keep = 10
  )
  {

    # Install backup gem and dependencies
    package { ['backup']  :
      ensure => installed,
      provider => 'gem',
    }

    package { ['libxslt1-dev']  :
      ensure => installed,
    }

    package { 'fog'  :
      provider => 'gem',
      ensure   => "~> 1.4.0",
      require => Package['libxslt1-dev']
    }

    $backup_conf_dir = '/etc/backup'
    $backup_cfg = "${backup_conf_dir}/backup.rb"

    # Backup script
    file { [$backup_conf_dir] :
      ensure  => directory,
      mode => 0700,
    }

    # Realize rails app definitions
    Firefield::Backup_def_rails_app <||>
    concat{ $backup_cfg:
      owner => root,
      group => root,
      mode  => 600
    }

    concat::fragment{"01_header":
      target => $backup_cfg,
      content => template("firefield/backups/rails_server_fragments/01_header.erb"),
      order   => 1,
   }

   concat::fragment{"99_footer":
     target => $backup_cfg,
     content => template("firefield/backups/rails_server_fragments/99_footer.erb"),
     order   => 99,
   }

   # Create a cron job
    cron { 'backup_cron':
      command => "backup perform -c ${backup_cfg} -t rails_server",
      user    => root,
      hour    => 1,
      minute  => 0,
      require => Concat[$backup_cfg],
    }

  }

  define on_demand_backup (
    $db_name,
    $db_user,
    $db_pass,
    $application_deploy_dir,
    $path,
    $on_demand_user = 'deployer',
  )
  {

    $backups_dir = "/var/backups/${on_demand_user}"

    # Backup script
    file { "on_demand_backup_for_${name}" :
      path    => $path,
      ensure  => file,
      content  => template("firefield/backups/rails_app_backup.erb"),
    }

  }


}
