class firefield {

  # Passenger and Nginx stuff
  #=====================================

  class passenger(
    $install_dir = $rails_server::nginx_install_dir,
    $ruby_home = $rails_server::ruby_home
  )
  {

    $sites_enabled_dir = "${install_dir}/conf/sites_enabled"

    # System vars
    Exec { path => ['/bin', '/usr/bin', '/usr/sbin', "${ruby_home}/bin" ] }


    package {['nginx-full', 'nginx-common']:
      ensure => purged,
    }

    package {'libcurl4-openssl-dev':
      ensure => installed,
    }

    # Installing passenger
    package {'passenger' :
      ensure => installed,
      provider => 'gem',
      require => Package['libcurl4-openssl-dev']
    }

    # Install nginx from source with the passenger module
    exec { 'passenger-install-nginx-module':
      command => "passenger-install-nginx-module --auto --prefix=${install_dir} --auto-download",
      creates => "${install_dir}/sbin/nginx",
      require => Package['passenger'],
    }

    # Sites enabled dir
    file { 'nginx_sites_enabled_dir' :
      path => $sites_enabled_dir,
      ensure => directory,
      require => Exec['passenger-install-nginx-module'],
    }

    # Nginx main conf
    file { 'nginx_main_conf' :
      path    => "${install_dir}/conf/nginx.conf",
      ensure  => file,
      mode => 0644,
      content  => template("firefield/nginx/passenger_nginx.conf.erb"),
      require => [Package['passenger'], Exec['passenger-install-nginx-module']],
    }

    # Init stuff
    file { 'nginx_init_script' :
      path    => "/etc/init.d/nginx",
      ensure  => file,
      mode => 0755,
      content  => template("firefield/nginx/nginx_init_script.erb"),
      require => Exec['passenger-install-nginx-module'],
    }

    service { 'nginx' :
      ensure => running,
      enable => true,
      hasstatus => true,
      hasrestart => true,
      require => File['nginx_init_script'],
    }

  }

  define passenger_vhost ($app_dir, $domains, $install_dir = $rails_server::nginx_install_dir
  ){
    $application = $name

    $ruby_home = $rails_server::ruby_home
    $sites_enabled_dir = "${install_dir}/conf/sites_enabled"

    # Nginx virtual host
    file { "nginx_virtual_host_${name}" :
      path    => "${sites_enabled_dir}/${$application}.conf",
      ensure  => file,
      mode => 0644,
      content  => template("firefield/nginx/passenger_nginx_vhost.erb"),
      require => File['nginx_sites_enabled_dir'],
    }
  }

}
